---
name: Bug report
about: Create a report to help us improve
title: "[BUG] "
labels: bug
assignees: henryiii, LovelyBuggies

---

**Describe the bug**

A clear and concise description of what the bug is.

**To Reproduce**

A clear and concise description of how this bug occurs.

**Expected behavior**

A clear and concise description of what you expected to happen.
